

*1) DOWNLOAD THE DATA
***First you need to download the dataset from the UKDATASERVICE at https://www.ukdataservice.ac.uk/get-data***
**you will need to register if you haven't already**
*specific link to more information about the Closer training dataset is here: https://discover.ukdataservice.ac.uk/catalogue/?sn=8205&type=Data%20catalogue

*2) PREPARE THE DATA
** Change the directory path to point to where you've stored the data** 
**run preparation code below**
****this will create the dataset CTD_1 for using the LDA methods 1 to 3*****
 
**use " $*PATH AND FILENAME.dta", clear

*****************************
*****PREPARATION CODE********
*****************************

**variables used in the analysis for rlinera, logistic and multinomial regression**
keep ncdsid bmi42 n920 n622 n016nmed n716dade n1171 bmi11

**creating missing "." for all missing codes in the dataset** 
foreach x of varlist n622-bmi42{
replace `x'=. if inrange(`x',-9,-1)
}
replace n1171=. if n1171==8

**identify missing observations with any missing data** 
gen miss1=.
replace miss1 = 0 if missing(bmi42, n920,  n622, n016nmed, n716dade, n1171, bmi11)
replace miss1 = 1 if!missing(bmi42, n920,  n622, n016nmed, n716dade, n1171, bmi11)
drop if miss1 == 0
drop miss1


**save	"$* PATH AND /CTD_1.dta", replace


******THIS IS THE POINT WHERE WE HAVE A CLEAN DATASET FOR CTD_1 (Methods 1 to 3)******
**************************************************************************************


**EXPLORING THE DESCRIPTIVE DATA**
describe
summarize bmi42 n920 bmi11 n622 n016nmed n716dade n1171 
sum bmi42 n920, detail 

**officially check for normality**
**number of different tests you can use show pictorially**
**mvtest norm bmi42 n920
**sktest norm bmi42 n920
qnorm bmi42
qnorm n920
**zscores**
histogram bmi42, frequency normal
hist zbmi42, frequency normal
**egen zbmi42 = std(bmi42)
**egen zn920 = std(n920)

**PREPARING OUR EXPLANATORY VARIABLES**
**recode variable n622 to sex**
codebook n622 
**create variables**
gen sex=.
replace sex = 1 if n622==2
replace sex = 0 if n622==1
label define sexL 0 "male" 1 "female" 
label values sex sexL
**recode social class n1171 to n1171_2**
codebook n1171 
tab n1171
gen n1171_2 = .
replace n1171_2 = 1 if n1171==1 | n1171==2
replace n1171_2 = 2 if n1171==3
replace n1171_2 = 3 if n1171==4
replace n1171_2 = 4 if n1171==5 | n1171==6
replace n1171_2 = 5 if n1171==7
label define n1171_2L 1 "I/II Prof & Managerial" 2  "III Skilled non-manual" 3 "III Skilled manual" 4 "IV Partly skilled" 5 "V unskilled" , modify
label values n1171_2 n1171_2L
tab n1171 n1171_2

save "$* PATH AND /CTD_1.dta", replace


***************************************************************
**METHOD 1: GENERAL LINEAR REGRESSION USING LONGITUDINAL DATA**
***************************************************************

**1) ensure you've examined the data
**2) prepared the explanatory variables

**M1: BMI at age 42 with one predictor (general ability at age 11)
reg bmi42 n920 
predict bmi_iq1
**scatter bmi42 n920
twoway (scatter bmi42 n920) (lfit bmi42 n920)

**M2: add covariates (gender and family background variables)


reg bmi42 n920 i.sex n016nmed n716dade i.n1171_2 

**TAKE OUT FATHER'S SOCIAL CLASS FROM THE MODEL. AS A RESULT FATHERS MINIMUM AGE OF LEAVING EDUCATION IS NOW SIGNIFICANT**
*run the syntax below:
*reg bmi42 n920 sex n016nmed n716dade

**M3: add BMI at age 11
reg bmi42 n920 i.sex n016nmed n716dade i.n1171_2 bmi11 

***regression DIAGNOSTICS***
*a) normality
predict bmi_iq2, resid
*kdensity bmi_iq2, normal
*pnorm bmi_iq2
qnorm bmi_iq2
swilk bmi_iq2
*b) heteroscedasticity
rvfplot
estat imtest
estat hettest




**********************************************************
**METHOD 2: LOGISTIC REGRESSION USING LONGITUDINAL DATA**
**********************************************************
**1) ensure you've examined the data
**2) prepared the explanatory variables

**CREATE BINARY OUTCOME MEASURE**
**using BMI CUT-OFFS FROM World Health Organisation (WHO) standards (http://apps.who.int/bmi/index.jsp?introPage=intro_3.htm**

gen obese42 = .
replace obese42 = 0 if inrange(bmi42,14,29.99999)
replace obese42 = 1 if inrange(bmi42,30,52)
label define obese42L 0 "not obese" 1 "obese", modify
label values obese42 obese42L

tab obese42

**M1: Obese or not at age 42 and one predictor (general ability at age 11)
logit obese42 n920
**note if you used  "logit obese42 n920, or" OR  "logistic obese42 n920", you would get the odds ratios and their confidence intervals, 

**M2: add covariates (gender and family background variables)


logit obese42 n920 i.sex n016nmed n716dade i.n1171_2 

**M3: add BMI at age 11
logit obese42 n920 i.sex n016nmed n716dade i.n1171_2 bmi11 
**use "logistic obese42 n920 i.sex n016nmed n716dade i.n1171_2 bmi11" to get the odds ratios for the final model

**test the overal effect of social class**
test 2.n1171_2 3.n1171_2 4.n1171_2 5.n1171_2
test 2.n1171_2 3.n1171_2

**predicted probabilities**
margins, at(n920=(10(10)80)) vsquish
**if you want to do the same with a categorical variable such as social class you can use "margins n1171_2, atmeans"
**you can also set the PP's for the continuous variables at the means of the other variables in the model**
marginsplot

***Hypothesis testing***
**contrasts between nested models**
**Model 0: Intercept only
quietly logit obese42  
est store M0
**Model 1: 'general ability' added
quietly logit obese42 n920 
est store M1
**Model 2: 'general ability' and covariates
quietly logit obese42 n920 i.sex n016nmed n716dade i.n1171_2 
est store M2
**Model 3: general ability', sex, family background and BMI at age 11
quietly logit obese42 n920 i.sex n016nmed n716dade i.n1171_2 bmi11 
est store M3

*Model 1 versus Model 0
lrtest M1 M0
*Model 2 versus Model 1
lrtest M2 M1
*Model 3 versus Model 2
lrtest M3 M2
*Model 3 versus Model 0
lrtest M3 M0

*********************************************************************
**METHOD 3: MULTINOMIAL LOGISTIC REGRESSION USING LONGITUDINAL DATA**
*********************************************************************

**1) ensure you've examined the data
**2) prepared the explanatory variables

**CREATE CATEGORICAL OUTCOME MEASURE**
**using BMI CUT-OFFS FROM World Health Organisation (WHO) standards (http://apps.who.int/bmi/index.jsp?introPage=intro_3.htm**


gen BMI42_C = .
replace BMI42_C = 1 if inrange(bmi42,14,24.99999)
replace BMI42_C = 2 if inrange(bmi42,25,29.99999)
replace BMI42_C = 3 if inrange(bmi42,30,52)
label define BMI42_CL 1 "normal/healthy" 2 "overweight" 3 "obese", modify
label values BMI42_C BMI42_CL

tab BMI42_C 

**M1: Obese and overweight compared to normal/healthy BMI at age 42 and one predictor (general ability at age 11)
mlogit BMI42_C n920, base(1)


**M2: add gender and family background
mlogit BMI42_C n920 i.sex n016nmed n716dade i.n1171_2, base(1) 

**M3: add BMI at age 11
mlogit BMI42_C n920 i.sex n016nmed n716dade i.n1171_2 bmi11, base(1)
**use 'mlogit BMI42_C n920 i.sex n016nmed n716dade i.n1171_2 bmi11, base(1) rrr' to get the relative risk ratios for the final model**

***testing differences between predictors across outcome categories***
**mothers education in overweight v obese categories**
test [overweight]n016nmed  =  [obese]n016nmed
**test the overal effect of social class**
test 2.n1171_2 3.n1171_2 4.n1171_2 5.n1171_2

**predicted probabilities**
margins, at(n920=(10(10)80)) predict(outcome(1)) vsquish
**if you want to do the same with a categorical variable such as social class you can use "margins n1171_2, atmeans"
**you can also set the PP's for the continuous variables at the means of the other variables in the model**

**we can also produce graphs with the predicted probabilities and confidence intervals**
margins, at(n920=(10(10)80)) predict(outcome(1)) vsquish
marginsplot, name(healthy)
margins, at(n920=(10(10)80)) predict(outcome(2)) vsquish
marginsplot, name(overweight)
margins, at(n920=(10(10)80)) predict(outcome(3)) vsquish
marginsplot, name(obese)
graph combine healthy overweight obese, ycommon


